@@ -136,7 +136,7 @@
 "nearloc" <- function(points, locations, positions=FALSE)
 {
   if(!is.data.frame(points) && is.list(points)){
-    points <- matrix(unlist(points[1:2]), nc=2)
+    points <- matrix(unlist(points[1:2]), ncol=2)
     backtolist <- TRUE
     backnames <- names(points[1:2])
   }
@@ -146,7 +146,7 @@
   if(is.data.frame(locations))
     locations <- as.matrix(locations[,1:2])
   if(is.list(locations))
-    locations <- matrix(unlist(locations[1:2]), nc=2)
+    locations <- matrix(unlist(locations[1:2]), ncol=2)
   if(ncol(locations) != 2)
     stop("locations must be a matrix, data.frame, or list")
   ind <- apply(loccoords(points, locations),1,which.min)
